diff mbox series

[1/3] mm: Use arch_make_folio_accessible() in gup_pte_range()

Message ID 20230915172829.2632994-2-willy@infradead.org (mailing list archive)
State New, archived
Headers show
Series Use arch_make_folio_accessible() everywhere | expand

Commit Message

Matthew Wilcox Sept. 15, 2023, 5:28 p.m. UTC
This function already uses folios, so convert the
arch_make_page_accessible() call to arch_make_folio_accessible().

Signed-off-by: Matthew Wilcox (Oracle) <willy@infradead.org>
---
 mm/gup.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
diff mbox series

Patch

diff --git a/mm/gup.c b/mm/gup.c
index 2f8a2d89fde1..ab8a0ebc728e 100644
--- a/mm/gup.c
+++ b/mm/gup.c
@@ -2622,13 +2622,13 @@  static int gup_pte_range(pmd_t pmd, pmd_t *pmdp, unsigned long addr,
 		}
 
 		/*
 		 * We need to make the page accessible if and only if we are
 		 * going to access its content (the FOLL_PIN case).  Please
 		 * see Documentation/core-api/pin_user_pages.rst for
 		 * details.
 		 */
 		if (flags & FOLL_PIN) {
-			ret = arch_make_page_accessible(page);
+			ret = arch_make_folio_accessible(folio);
 			if (ret) {
 				gup_put_folio(folio, 1, flags);
 				goto pte_unmap;
@@ -2622,13 +2622,13 @@  static int gup_pte_range(pmd_t pmd, pmd_t *pmdp, unsigned long addr,
 
 		/*
-		 * We need to make the page accessible if and only if we are
+		 * We need to make the folio accessible if and only if we are
 		 * going to access its content (the FOLL_PIN case).  Please
 		 * see Documentation/core-api/pin_user_pages.rst for